Stan Math Library: stan/math/prim/scal/fun/modified_bessel_second_kind.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

modified_bessel_second_kind.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_MODIFIED_BESSEL_SECOND_KIND_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_MODIFIED_BESSEL_SECOND_KIND_HPP
3
4 #include <boost/math/special_functions/bessel.hpp>
5
6 namespace stan {
7 namespace math {
8
40 template<typename T2>
41 inline T2
42 modified_bessel_second_kind(const int v, const T2 z) {
43 return boost::math::cyl_bessel_k(v, z);
44 }
45
46 }
47 }
48
49 #endif
stan::math::modified_bessel_second_kind
fvar< T > modified_bessel_second_kind(int v, const fvar< T > &z)
Definition: modified_bessel_second_kind.hpp:15
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.